:'====================================================================
:'                       Header file for:
:'                       H I M E . d l l
:'          Huge Integer Math and Encryption library dll
:'                            V 2.05
:'                 (C) 2002-2008 DevOTechS
:'                 e-mail: support@devotechs.com
:'====================================================================

:'--------------------------------------------------------------------
:' Constants

:'When calling :'hi_GetGlobalError:', following bits might be set:
:'ErrorBit name     	          	  	  Value      	Corresponding function
CONST hi_ErrBit_Div                = &h1       :' hi_Div
CONST hi_ErrBit_ModInv             = &h2       :' hi_ModInv
CONST hi_ErrBit_GenerateRSAKeys    = &h4       :' hi_GenerateRSAKeys
CONST hi_ErrBit_Sub                = &h8       :' hi_Sub
CONST hi_ErrBit_Encrypt_RSA        = &h10      :' hi_Encrypt_RSA
CONST hi_ErrBit_Decrypt_RSA        = &h20      :' hi_Decrypt_RSA
CONST hi_ErrBit_Encrypt_AES_CBC    = &h40      :' hi_Encrypt_AES_CBC

CONST hi_ErrBit_Decrypt_AES_CBC    = &h80      :' hi_Decrypt_AES_CBC
CONST hi_ErrBit_Encrypt_AES_ECB    = &h100     :' hi_Encrypt_AES_ECB
CONST hi_ErrBit_Decrypt_AES_ECB    = &h200     :' hi_Decrypt_AES_ECB
CONST hi_ErrBit_Encrypt_AES_1Block = &h400     :' hi_Encrypt_AES_1Block
CONST hi_ErrBit_Decrypt_AES_1Block = &h800     :' hi_Decrypt_AES_1Block
CONST hi_ErrBit_Base642Huge        = &h1000    :' hi_Base642Huge
CONST hi_ErrBit_DiffieHellman      = &h2000    :' hi_DH_Step1 AND hi_DH_Step2

CONST hi_ErrBit_ConcatByte         = &h4000    :' hi_RegConcatByte
CONST hi_ErrBit_EnDecrypt_Arc4     = &h8000    :' hi_Encrypt_Arc4, hi_Decrypt_Arc4
CONST hi_ErrBit_Rec_GetField       = &h10000   :' hi_Rec_GetField
CONST hi_ErrBit_Rec_GetNrFields    = &h20000   :' hi_Rec_GetNrFields
CONST hi_ErrBit_RegAllocRange      = &h40000   :' hi_RegAllocateRange
CONST hi_ErrBit_CompDecompress     = &h80000   :' hi_Compress, hi_Decompress

CONST hi_ErrBit_FileError          = &h100000  :' hi_PutRegFromFile, hi_GetRegToFile, hi_ShredFile
CONST hi_ErrBit_BitManipulation    = &h200000  :' hi_And, hi_Or, hi_Xor 

CONST hi_ErrBit_RootN              = &h400000  :'23
CONST hi_ErrBit_HMAC               = &h800000  :'24


:'Constants for hi_SetOption and hi_GetOption
CONST hi_Opt_NrPrimes        = 1     :'1 : number of primes that are currently stored in HIMEs prime number table
CONST hi_Opt_NrRegisters     = 2     :'2 : the number of HIME registers
CONST hi_Opt_Kara_Thresh_mul = 3     :'3 : the Karatsuba threshold value for hi_mul (multiplication).
CONST hi_Opt_Kara_Thresh_sq  = 4     :'4 : the Karatsuba threshold value for hi_square (squaring).
CONST hi_Opt_Zlib_Handle     = 5     :'5 : the HIME_Zlib.dll handle.  
CONST hi_Opt_JCalg1_handle   = 6     :'6 : the HIME_JCalg1.dll handle.
CONST hi_Opt_Endianness      = 7     :'7 : the endianness. Used for HMAC
CONST hi_Opt_Reverse         = 8     :'8 : for reversing hash data. Used for HMAC


:'Constants for hi_HMAC_FIPS198a
CONST hi_HMAC_Hash_MD5    = 1
CONST hi_HMAC_Hash_SHA1   = 2
CONST hi_HMAC_Hash_SHA256 = 3
CONST hi_HMAC_Hash_SHA512 = 4


:'Constants for Synchronous/Asynchronous functions
CONST hi_Command_Start_Sync  = 1
CONST hi_Command_Start_Async = 2
CONST hi_Command_Abort       = 3

:'--------------------------------------------------------------------


:'--------------------------------------------------------------------
:' Declarations 
DECLARE "HIME.DLL", hi_Add                           ALIAS HI_ADD                           ( lReg1 AS INT BYREF, lReg2 AS INT BYREF, lReg_Result AS INT BYREF ), INT                                                                                                      
DECLARE "HIME.DLL", hi_And                           ALIAS HI_AND                           ( lReg1 AS INT BYREF, lReg2 AS INT BYREF, lReg_Result AS INT BYREF ), INT                                                                                                                          
DECLARE "HIME.DLL", hi_Base642Huge                   ALIAS HI_BASE642HUGE                   ( lRegIn AS INT BYREF, lRegOut AS INT BYREF ), INT                                                                                                                                           
DECLARE "HIME.DLL", hi_Bin2Huge                      ALIAS HI_BIN2HUGE                      ( lRegIn AS INT BYREF, lRegOut AS INT BYREF ), INT                                                                                                                                           
DECLARE "HIME.DLL", hi_BitClear                      ALIAS HI_BITCLEAR                      ( Bitnr AS INT BYREF, lReg1 AS INT BYREF, lReg_Result AS INT BYREF ), INT                                                                                                                          
DECLARE "HIME.DLL", hi_BitSet                        ALIAS HI_BITSET                        ( Bitnr AS INT BYREF, lReg1 AS INT BYREF, lReg_Result AS INT BYREF ), INT                                                                                                                          
DECLARE "HIME.DLL", hi_BitToggle                     ALIAS HI_BITTOGGLE                     ( Bitnr AS INT BYREF, lReg1 AS INT BYREF, lReg_Result AS INT BYREF ), INT                                                                                                                          
DECLARE "HIME.DLL", hi_BreakString                   ALIAS HI_BREAKSTRING                   ( lRegIn AS INT BYREF, CharsInChunk AS INT BYREF, NrOfSpaces AS INT BYREF, ChunksInLine AS INT BYREF, lReg_Result AS INT BYREF ), INT                                                                          
DECLARE "HIME.DLL", hi_CheckTestVectors_AES          ALIAS HI_CHECKTESTVECTORS_AES          ( ), INT                                                                                                                                                                         
DECLARE "HIME.DLL", hi_CheckTestVectors_Arc4         ALIAS HI_CHECKTESTVECTORS_ARC4         ( ), INT                                                                                                                                                                         
DECLARE "HIME.DLL", hi_CheckTestVectors_HMAC_FIPS198 ALIAS HI_CHECKTESTVECTORS_HMAC_FIPS198 ( ), INT                                                                                                                                                                         
DECLARE "HIME.DLL", hi_CheckTestVectors_MD5          ALIAS HI_CHECKTESTVECTORS_MD5          ( ), INT                                                                                                                                                                         
DECLARE "HIME.DLL", hi_CheckTestVectors_SHA_1        ALIAS HI_CHECKTESTVECTORS_SHA_1        ( ), INT                                                                                                                                                                         
DECLARE "HIME.DLL", hi_CheckTestVectors_SHA_256      ALIAS HI_CHECKTESTVECTORS_SHA_256      ( ), INT                                                                                                                                                                         
DECLARE "HIME.DLL", hi_CheckTestVectors_SHA_512      ALIAS HI_CHECKTESTVECTORS_SHA_512      ( ), INT                                                                                                                                                                         
DECLARE "HIME.DLL", hi_Compress                      ALIAS HI_COMPRESS                      ( lRegIn AS INT BYREF, Algo AS INT BYREF, lRegOut AS INT BYREF ), INT                                                                                                                              
DECLARE "HIME.DLL", hi_CopyReg                       ALIAS HI_COPYREG                       ( lRegSource AS INT BYREF, lRegTarget AS INT BYREF ), INT                                                                                                                                    
DECLARE "HIME.DLL", hi_Dec2Huge                      ALIAS HI_DEC2HUGE                      ( lRegIn AS INT BYREF, lRegOut AS INT BYREF ), INT                                                                                                                                           
DECLARE "HIME.DLL", hi_Decompress                    ALIAS HI_DECOMPRESS                    ( lRegIn AS INT BYREF, lRegOut AS INT BYREF ), INT                                                                                                                                           
DECLARE "HIME.DLL", hi_Decr                          ALIAS HI_DECR                          ( lReg1 AS INT BYREF, lReg_Result AS INT BYREF ), INT                                                                                                                                        
DECLARE "HIME.DLL", hi_Decrypt_AES_1Block            ALIAS HI_DECRYPT_AES_1BLOCK            ( lReg_Cipher AS INT BYREF, lReg_Key AS INT BYREF, lReg_Plain AS INT BYREF ), INT                                                                                                                  
DECLARE "HIME.DLL", hi_Decrypt_AES_CBC               ALIAS HI_DECRYPT_AES_CBC               ( lReg_Cipher AS INT BYREF, lReg_Key AS INT BYREF, lReg_Plain AS INT BYREF ), INT                                                                                                                  
DECLARE "HIME.DLL", hi_Decrypt_AES_ECB               ALIAS HI_DECRYPT_AES_ECB               ( lReg_Cipher AS INT BYREF, lReg_Key AS INT BYREF, lReg_Plain AS INT BYREF ), INT                                                                                                                  
DECLARE "HIME.DLL", hi_Decrypt_Arc4                  ALIAS HI_DECRYPT_ARC4                  ( lReg_Cipher AS INT BYREF, lReg_Key AS INT BYREF, lReg_Plain AS INT BYREF, BytesToDiscard AS INT), INT                                                                                            
DECLARE "HIME.DLL", hi_Decrypt_RSA                   ALIAS HI_DECRYPT_RSA                   ( lReg_Cipher AS INT BYREF, lReg_hd AS INT BYREF, lReg_hModul AS INT BYREF, lReg_Plain AS INT BYREF ), INT                                                                                               
DECLARE "HIME.DLL", hi_Decrypt_RSA_CRT               ALIAS HI_DECRYPT_RSA_CRT               ( lReg_Cipher AS INT BYREF, lReg_p AS INT BYREF, lReg_q AS INT BYREF, lReg_dp AS INT BYREF, lReg_dq AS INT BYREF, lReg_PInvQ AS INT BYREF, lReg_Plain AS INT BYREF ), INT                                                  
DECLARE "HIME.DLL", hi_DH_GenParams                  ALIAS HI_DH_GENPARAMS                  ( lBitLength AS INT BYREF, lRegP AS INT BYREF, lRegG AS INT BYREF ), INT                                                                                                                           
DECLARE "HIME.DLL", hi_DH_Step1                      ALIAS HI_DH_STEP1                      ( lRegP AS INT BYREF, lRegG AS INT BYREF, lPriv AS INT BYREF, lPub AS INT BYREF ), INT                                                                                                                   
DECLARE "HIME.DLL", hi_DH_Step2                      ALIAS HI_DH_STEP2                      ( lRegP AS INT BYREF, lPub AS INT BYREF, lPriv AS INT BYREF, lShared AS INT BYREF ), INT                                                                                                                 
DECLARE "HIME.DLL", hi_Div                           ALIAS HI_DIV                           ( lReg1 AS INT BYREF, lReg2 AS INT BYREF, lReg_Quot AS INT BYREF, lReg_Rem AS INT BYREF ), INT                                                                                                           
DECLARE "HIME.DLL", hi_Div_V1                        ALIAS HI_DIV_V1                        ( lReg1 AS INT BYREF, lReg2 AS INT BYREF, lReg_Quot AS INT BYREF, lReg_Rem AS INT BYREF ), INT                                                                                                           
DECLARE "HIME.DLL", hi_DivBy2                        ALIAS HI_DIVBY2                        ( lReg1 AS INT BYREF, lReg_Quot AS INT BYREF, lReg_Rem AS INT BYREF ), INT                                                                                                                         
DECLARE "HIME.DLL", hi_Encrypt_AES_1Block            ALIAS HI_ENCRYPT_AES_1BLOCK            ( lReg_Plain AS INT BYREF, lReg_Key AS INT BYREF, lReg_Cipher AS INT BYREF ), INT                                                                                                                  
DECLARE "HIME.DLL", hi_Encrypt_AES_CBC               ALIAS HI_ENCRYPT_AES_CBC               ( lReg_Plain AS INT BYREF, lReg_Key AS INT BYREF, lReg_IV AS INT BYREF, lReg_Cipher AS INT BYREF ), INT                                                                                                  
DECLARE "HIME.DLL", hi_Encrypt_AES_ECB               ALIAS HI_ENCRYPT_AES_ECB               ( lReg_Plain AS INT BYREF, lReg_Key AS INT BYREF, lReg_Cipher AS INT BYREF ), INT                                                                                                                  
DECLARE "HIME.DLL", hi_Encrypt_Arc4                  ALIAS HI_ENCRYPT_ARC4                  ( lReg_Plain AS INT BYREF, lReg_Key AS INT BYREF, lReg_Cipher AS INT BYREF, BytesToDiscard AS INT), INT                                                                                            
DECLARE "HIME.DLL", hi_Encrypt_RSA                   ALIAS HI_ENCRYPT_RSA                   ( lReg_Plain AS INT BYREF, lReg_he AS INT BYREF, lReg_hModul AS INT BYREF, lReg_Cipher AS INT BYREF ), INT                                                                                               
DECLARE "HIME.DLL", hi_ExtEuclidAlgo                 ALIAS HI_EXTEUCLIDALGO                 ( lReg_A AS INT BYREF, lReg_B AS INT BYREF, ForcePositiveResults AS INT BYREF, lReg_GCD AS INT BYREF, lReg_x AS INT BYREF, lReg_y AS INT BYREF, Sign_x AS INT BYREF, Sign_y AS INT), INT                                   
DECLARE "HIME.DLL", hi_Factor_Pollards_Rho           ALIAS HI_FACTOR_POLLARDS_RHO           ( lReg_N AS INT BYREF, lReg_x0 AS INT BYREF, lm AS INT BYREF, lReg_c AS INT BYREF, lReg_Command AS INT BYREF, lReg_Status AS INT BYREF, lReg_g AS INT BYREF ), INT
DECLARE "HIME.DLL", HI_FACTOR_TRIALDIV               ALIAS HI_FACTOR_TRIALDIV               ( lReg1 AS INT BYREF, lP1 AS INT BYREF, lP2 AS INT BYREF, lReg_Result AS INT BYREF ), INT                                                                                                                
DECLARE "HIME.DLL", hi_Factors                       ALIAS HI_FACTORS                       ( lReg_N AS INT BYREF, lReg_Command AS INT BYREF, lReg_Status AS INT BYREF, lReg_Factors AS INT BYREF ), INT                                                                                             
DECLARE "HIME.DLL", hi_FormatAsHuge                  ALIAS HI_FORMATASHUGE                  ( lReg1 AS INT BYREF, lReg2 AS INT BYREF ), INT                                                                                                                                              
DECLARE "HIME.DLL", hi_GCD                           ALIAS HI_GCD                           ( lReg1 AS INT BYREF, lReg2 AS INT BYREF, lReg_Result AS INT BYREF ), INT                                                                                                                          
DECLARE "HIME.DLL", hi_GenerateBBSRandomBits         ALIAS HI_GENERATEBBSRANDOMBITS         ( lBytes AS INT BYREF, lMultipleBits AS INT BYREF, lReg_SSeed AS INT BYREF, lReg_Modul AS INT BYREF, lReg_Result AS INT BYREF, lReg_ESeed AS INT BYREF ), INT                                                        
DECLARE "HIME.DLL", hi_GeneratePrime                 ALIAS HI_GENERATEPRIME                 ( lLengthBits AS INT BYREF, lPrimeTests AS INT BYREF, lReg_Result AS INT BYREF ), INT                                                                                                              
DECLARE "HIME.DLL", hi_GenerateRandom                ALIAS HI_GENERATERANDOM                ( lLengthBits AS INT BYREF, lReg_Result AS INT BYREF ), INT                                                                                                                                  
DECLARE "HIME.DLL", hi_GenerateRSAKeys               ALIAS HI_GENERATERSAKEYS               ( lBitLength AS INT BYREF, lPrimeTests AS INT BYREF, lReg_he AS INT BYREF, lReg_hd AS INT BYREF, lReg_Modul AS INT BYREF ), INT                                                                                
DECLARE "HIME.DLL", hi_GenerateRSAKeys_CRT           ALIAS HI_GENERATERSAKEYS_CRT           ( lBitLength AS INT BYREF, lPrimeTests AS INT BYREF, lReg_he AS INT BYREF, lReg_Modul AS INT BYREF, lReg_hp AS INT BYREF, lReg_hq AS INT BYREF, lReg_hdp AS INT BYREF, lReg_hdq AS INT BYREF, lReg_hPInvQ AS INT BYREF ), INT
DECLARE "HIME.DLL", hi_GenerateRSARandomBits         ALIAS HI_GENERATERSARANDOMBITS         ( lBytes AS INT BYREF, lReg_SSeed AS INT BYREF, lReg_he AS INT BYREF, lReg_Modul AS INT BYREF, lReg_Result AS INT BYREF, lReg_EndSeed AS INT), INT                                                             
DECLARE "HIME.DLL", hi_GetGlobalError                ALIAS HI_GETGLOBALERROR                ( ), INT                                                                                                                                                                         
DECLARE "HIME.DLL", hi_GetOption                     ALIAS HI_GETOPTION                     ( lOption AS INT BYREF, lParam AS INT BYREF ), INT                                                                                                                                           
DECLARE "HIME.DLL", hi_GetPrimeFromTable             ALIAS HI_GETPRIMEFROMTABLE             ( lIndex AS INT BYREF, lReg_Result AS INT BYREF ), INT                                                                                                                                       
DECLARE "HIME.DLL", hi_GetRandomBytesFromServer      ALIAS HI_GETRANDOMBYTESFROMSERVER      ( Server_ AS INT BYREF, Port_ AS INT BYREF, Command AS INT BYREF, TimeOut_ AS INT BYREF, NumberBytes AS INT BYREF, lReg AS INT BYREF ), INT                                                                          
DECLARE "HIME.DLL", hi_GetReg                        ALIAS HI_GETREG                        ( lReg AS INT BYREF ), STRING                                                                                                                                                          
DECLARE "HIME.DLL", hi_GetRegAdd                     ALIAS HI_GETREGADD                     ( lReg AS INT BYREF, lAddress AS INT BYREF, lLen AS INT BYREF ), INT                                                                                                                               
DECLARE "HIME.DLL", hi_GetRegAdd2                    ALIAS HI_GETREGADD2                    ( lReg AS INT BYREF, lAddress AS INT BYREF ), INT                                                                                                                                            
DECLARE "HIME.DLL", hi_GetRegAsciiz1                 ALIAS HI_GETREGASCIIZ1                 ( lReg AS INT BYREF ), INT                                                                                                                                                             
DECLARE "HIME.DLL", hi_GetRegAsciiz2                 ALIAS HI_GETREGASCIIZ2                 ( lReg AS INT BYREF, azData AS string ), INT                                                                                                                                           
DECLARE "HIME.DLL", hi_GetRegByte                    ALIAS HI_GETREGBYTE                    ( lReg AS INT BYREF, index AS INT BYREF ), INT                                                                                                                                               
DECLARE "HIME.DLL", hi_GetRegUINT                    ALIAS HI_GETREGDWORD                   ( lReg AS INT BYREF ), UINT                                                                                                                                                           
DECLARE "HIME.DLL", hi_GetRegINT                     ALIAS HI_GETREGINT                     ( lReg AS INT BYREF ), INT                                                                                                                                                             
DECLARE "HIME.DLL", hi_GetRegToClipboard             ALIAS HI_GETREGTOCLIPBOARD             ( lReg AS INT BYREF ), INT                                                                                                                                                             
DECLARE "HIME.DLL", hi_GetRegToFile                  ALIAS HI_GETREGTOFILE                  ( lReg AS INT BYREF, Mode AS INT BYREF, lReg_FileName AS INT BYREF ), INT                                                                                                                          
DECLARE "HIME.DLL", hi_Hash_CRC32                    ALIAS HI_HASH_CRC32                    ( lRegIn AS INT BYREF, lRegOut AS INT BYREF ), INT                                                                                                                                           
DECLARE "HIME.DLL", hi_Hash_MD5                      ALIAS HI_HASH_MD5                      ( lRegIn AS INT BYREF, lRegOut AS INT BYREF ), INT                                                                                                                                           
DECLARE "HIME.DLL", hi_Hash_SHA_1                    ALIAS HI_HASH_SHA_1                    ( lRegIn AS INT BYREF, lRegOut AS INT BYREF ), INT                                                                                                                                           
DECLARE "HIME.DLL", hi_Hash_SHA_256                  ALIAS HI_HASH_SHA_256                  ( lRegIn AS INT BYREF, lRegOut AS INT BYREF ), INT                                                                                                                                           
DECLARE "HIME.DLL", hi_Hash_SHA_512                  ALIAS HI_HASH_SHA_512                  ( lRegIn AS INT BYREF, lRegOut AS INT BYREF ), INT                                                                                                                                           
DECLARE "HIME.DLL", hi_Hex2Huge                      ALIAS HI_HEX2HUGE                      ( lRegIn AS INT BYREF, lRegOut AS INT BYREF ), INT                                                                                                                                           
DECLARE "HIME.DLL", hi_HIMEParams_LoadFromFile       ALIAS HI_HIMEPARAMS_LOADFROMFILE       ( lReg_FileName AS INT BYREF ), INT                                                                                                                                                    
DECLARE "HIME.DLL", hi_HIMEParams_SaveToFile         ALIAS HI_HIMEPARAMS_SAVETOFILE         ( lReg_FileName AS INT BYREF ), INT                                                                                                                                                    
DECLARE "HIME.DLL", hi_HMAC_FIPS198                  ALIAS HI_HMAC_FIPS198                  ( lReg_Key AS INT BYREF, lReg_Message AS INT BYREF, lB AS INT BYREF, lAlgo AS INT BYREF, lReg_HMAC AS INT BYREF ), INT                                                                                         
DECLARE "HIME.DLL", hi_Huge2Base64                   ALIAS HI_HUGE2BASE64                   ( lRegIn AS INT BYREF, lRegOut AS INT BYREF ), INT                                                                                                                                           
DECLARE "HIME.DLL", hi_Huge2Bin                      ALIAS HI_HUGE2BIN                      ( lRegIn AS INT BYREF, lRegOut AS INT BYREF ), INT                                                                                                                                           
DECLARE "HIME.DLL", hi_Huge2Dec                      ALIAS HI_HUGE2DEC                      ( lRegIn AS INT BYREF, lRegOut AS INT BYREF ), INT                                                                                                                                           
DECLARE "HIME.DLL", hi_Huge2Hex                      ALIAS HI_HUGE2HEX                      ( lRegIn AS INT BYREF, lRegOut AS INT BYREF ), INT                                                                                                                                           
DECLARE "HIME.DLL", hi_Incr                          ALIAS HI_INCR                          ( lReg1 AS INT BYREF, lReg_Result AS INT BYREF ), INT                                                                                                                                        
DECLARE "HIME.DLL", hi_InitBBS                       ALIAS HI_INITBBS                       ( lBitLength AS INT BYREF, lPrimeTests AS INT BYREF, lReg_Modul AS INT BYREF, lReg_Seed AS INT BYREF ), INT                                                                                              
DECLARE "HIME.DLL", hi_IsBitSet                      ALIAS HI_ISBITSET                      ( Bitnr AS INT BYREF, lReg1 AS INT BYREF ), INT                                                                                                                                              
DECLARE "HIME.DLL", HI_ISEQUAL                       ALIAS HI_ISEQUAL                       ( lReg1 AS INT BYREF, lReg2 AS INT BYREF ), INT                                                                                                                                              
DECLARE "HIME.DLL", hi_IsLess                        ALIAS HI_ISLESS                        ( lReg1 AS INT BYREF, lReg2 AS INT BYREF ), INT                                                                                                                                              
DECLARE "HIME.DLL", hi_IsNotEqual                    ALIAS HI_ISNOTEQUAL                    ( lReg1 AS INT BYREF, lReg2 AS INT BYREF ), INT                                                                                                                                              
DECLARE "HIME.DLL", hi_IsOdd                         ALIAS HI_ISODD                         ( lReg1 AS INT BYREF ), INT                                                                                                                                                            
DECLARE "HIME.DLL", hi_IsPrime_Div                   ALIAS HI_ISPRIME_DIV                   ( lReg1 AS INT BYREF ), INT                                                                                                                                                            
DECLARE "HIME.DLL", hi_IsPrime_F                     ALIAS HI_ISPRIME_F                     ( lTests AS INT BYREF, lReg1 AS INT BYREF ), INT                                                                                                                                             
DECLARE "HIME.DLL", hi_IsPrime_RB                    ALIAS HI_ISPRIME_RB                    ( lTests AS INT BYREF, lReg1 AS INT BYREF ), INT                                                                                                                                             
DECLARE "HIME.DLL", hi_IsPrime_Slow                  ALIAS HI_ISPRIME_SLOW                  ( lReg1 AS INT BYREF ), INT                                                                                                                                                            
DECLARE "HIME.DLL", hi_IsRegAllocated                ALIAS HI_ISREGALLOCATED                ( lReg AS INT BYREF ), INT                                                                                                                                                             
DECLARE "HIME.DLL", hi_IsRelPrime                    ALIAS HI_ISRELPRIME                    ( lReg1 AS INT BYREF, lReg2 AS INT BYREF ), INT                                                                                                                                              
DECLARE "HIME.DLL", hi_IsZero                        ALIAS HI_ISZERO                        ( lReg1 AS INT BYREF ), INT                                                                                                                                                            
DECLARE "HIME.DLL", hi_Mod                           ALIAS HI_MOD                           ( lReg1 AS INT BYREF, lReg2 AS INT BYREF, lReg_Result AS INT BYREF ), INT                                                                                                                          
DECLARE "HIME.DLL", hi_ModInv                        ALIAS HI_MODINV                        ( lReg1 AS INT BYREF, lReg2 AS INT BYREF, lReg_Result AS INT BYREF ), INT                                                                                                                          
DECLARE "HIME.DLL", hi_Mul                           ALIAS HI_MUL                           ( lReg1 AS INT BYREF, lReg2 AS INT BYREF, lReg_Result AS INT BYREF ), INT                                                                                                                          
DECLARE "HIME.DLL", hi_MulBy2                        ALIAS HI_MULBY2                        ( lReg1 AS INT BYREF, lReg_Result AS INT BYREF ), INT                                                                                                                                        
DECLARE "HIME.DLL", hi_Not                           ALIAS HI_NOT                           ( lReg1 AS INT BYREF, lReg_Result AS INT BYREF ), INT                                                                                                                                        
DECLARE "HIME.DLL", hi_Or                            ALIAS HI_OR                            ( lReg1 AS INT BYREF, lReg2 AS INT BYREF, lReg_Result AS INT BYREF ), INT                                                                                                                          
DECLARE "HIME.DLL", hi_Pow                           ALIAS HI_POW                           ( lReg1 AS INT BYREF, lReg2 AS INT BYREF, lReg_Result AS INT BYREF ), INT                                                                                                                          
DECLARE "HIME.DLL", hi_PowMod                        ALIAS HI_POWMOD                        ( lReg1 AS INT BYREF, lReg2 AS INT BYREF, lReg3 AS INT BYREF, lReg_Result AS INT BYREF ), INT                                                                                                            
DECLARE "HIME.DLL", hi_PutReg                        ALIAS HI_PUTREG                        ( h AS STRING, lReg AS INT BYREF ), INT                                                                                                                                                
DECLARE "HIME.DLL", hi_PutRegAdd                     ALIAS HI_PUTREGADD                     ( lAddress AS INT BYREF, LLen AS INT BYREF, lReg AS INT BYREF ), INT                                                                                                                               
DECLARE "HIME.DLL", hi_PutRegAsciiz                  ALIAS HI_PUTREGASCIIZ                  ( azData AS string, lReg AS INT BYREF ), INT                                                                                                                                           
DECLARE "HIME.DLL", hi_PutRegDword                   ALIAS HI_PUTREGDWORD                   ( dData AS DWORD, lReg AS INT BYREF ), INT                                                                                                                                             
DECLARE "HIME.DLL", hi_PutRegFromClipboard           ALIAS HI_PUTREGFROMCLIPBOARD           ( lReg AS INT BYREF ), INT                                                                                                                                                             
DECLARE "HIME.DLL", hi_PutRegFromFile                ALIAS HI_PUTREGFROMFILE                ( lReg_FileName AS INT BYREF, lReg AS INT BYREF ), INT                                                                                                                                       
DECLARE "HIME.DLL", hi_PutRegINT                     ALIAS HI_PUTREGINT                     ( lData AS INT BYREF, lReg AS INT BYREF ), INT                                                                                                                                               
DECLARE "HIME.DLL", hi_ReadPrimes                    ALIAS HI_READPRIMES                    ( lPrimesToRead AS INT BYREF ), INT                                                                                                                                                    
DECLARE "HIME.DLL", hi_Rec_AddField                  ALIAS HI_REC_ADDFIELD                  ( Fld AS INT BYREF, Rec AS INT BYREF ), INT                                                                                                                                                  
DECLARE "HIME.DLL", hi_Rec_GetField                  ALIAS HI_REC_GETFIELD                  ( Rec AS INT BYREF, Index AS INT BYREF, Fld AS INT BYREF ), INT                                                                                                                                    
DECLARE "HIME.DLL", hi_Rec_GetNrFields               ALIAS HI_REC_GETNRFIELDS               ( Rec AS INT BYREF ), INT                                                                                                                                                              
DECLARE "HIME.DLL", hi_RegAllocate                   ALIAS HI_REGALLOCATE                   ( ), INT                                                                                                                                                                         
DECLARE "HIME.DLL", hi_RegAllocateMultiple           ALIAS HI_REGALLOCATEMULTIPLE           ( lRegs AS INT BYREF ), INT                                                                                                                                                            
DECLARE "HIME.DLL", hi_RegAllocateRange              ALIAS HI_REGALLOCATERANGE              ( lFirstReg AS INT BYREF, lLastReg AS INT BYREF ), INT                                                                                                                                       
DECLARE "HIME.DLL", hi_RegChangeEndian               ALIAS HI_REGCHANGEENDIAN               ( lReg1 AS INT BYREF, lReg_Result AS INT BYREF ), INT                                                                                                                                        
DECLARE "HIME.DLL", hi_RegClear                      ALIAS HI_REGCLEAR                      ( lReg AS INT BYREF ), INT                                                                                                                                                             
DECLARE "HIME.DLL", hi_RegCompare                    ALIAS HI_REGCOMPARE                    ( lReg1 AS INT BYREF, lReg2 AS INT BYREF ), INT                                                                                                                                              
DECLARE "HIME.DLL", hi_RegConcatByte                 ALIAS HI_REGCONCATBYTE                 ( lReg AS INT BYREF, lVal AS INT BYREF ), INT                                                                                                                                                
DECLARE "HIME.DLL", hi_RegConcatReg                  ALIAS HI_REGCONCATREG                  ( lReg1 AS INT BYREF, lReg2 AS INT BYREF, lReg3 AS INT BYREF ), INT                                                                                                                                
DECLARE "HIME.DLL", hi_RegGetLen                     ALIAS HI_REGGETLEN                     ( lReg AS INT BYREF ), INT                                                                                                                                                             
DECLARE "HIME.DLL", hi_Register                      ALIAS HI_REGISTER                      ( lReg1 AS INT BYREF ), INT                                                                                                                                                            
DECLARE "HIME.DLL", HI_REGMAXALLOCATED               ALIAS HI_REGMAXALLOCATED               ( ), INT                                                                                                                                                                         
DECLARE "HIME.DLL", hi_RegReverse                    ALIAS HI_REGREVERSE                    ( lReg1 AS INT BYREF, lReg_Result AS INT BYREF ), INT                                                                                                                                        
DECLARE "HIME.DLL", hi_RegSplit                      ALIAS HI_REGSPLIT                      ( lRegIn AS INT BYREF, lBytes AS INT BYREF, lRegL AS INT BYREF, lRegR AS INT BYREF ), INT                                                                                                                
DECLARE "HIME.DLL", hi_RegUnAllocate                 ALIAS HI_REGUNALLOCATE                 ( lReg AS INT BYREF ), INT                                                                                                                                                             
DECLARE "HIME.DLL", hi_RegUnAllocateRange            ALIAS HI_REGUNALLOCATERANGE            ( lFirstReg AS INT BYREF, lLastReg AS INT BYREF ), INT                                                                                                                                       
DECLARE "HIME.DLL", hi_RegWipe                       ALIAS HI_REGWIPE                       ( lReg AS INT BYREF, Mode AS INT BYREF, Clr AS INT BYREF ), INT                                                                                                                                    
DECLARE "HIME.DLL", hi_Root_N                        ALIAS HI_ROOT_N                        ( lReg1 AS INT BYREF, lN AS INT BYREF, lCalcRem AS INT BYREF, lReg_Root AS INT BYREF, lReg_Rem AS INT BYREF ), INT                                                                                             
DECLARE "HIME.DLL", hi_Root_Sqrt                     ALIAS HI_ROOT_SQRT                     ( lReg1 AS INT BYREF, lCalcRem AS INT BYREF, lReg_Root AS INT BYREF, lReg_Rem AS INT BYREF ), INT                                                                                                        
DECLARE "HIME.DLL", hi_RSA_Pad_PKCS1_1_5             ALIAS HI_RSA_PAD_PKCS1_1_5             ( lReg_Plaintext AS INT BYREF, lReg_Modul AS INT BYREF, lReg_Result AS INT BYREF ), INT                                                                                                            
DECLARE "HIME.DLL", hi_RSA_Unpad_PKCS1_1_5           ALIAS HI_RSA_UNPAD_PKCS1_1_5           ( lReg_PaddedPlaintext AS INT BYREF, lReg_Plaintext AS INT), INT                                                                                                                       
DECLARE "HIME.DLL", hi_SetOption                     ALIAS HI_SETOPTION                     ( lOption AS INT BYREF, lParam AS INT BYREF ), INT                                                                                                                                           
DECLARE "HIME.DLL", hi_ShredDisk                     ALIAS HI_SHREDDISK                     ( lReg_DiskName AS INT BYREF, Passes AS INT BYREF, Algo AS INT BYREF, Parameter AS INT BYREF, lReg_Command AS INT BYREF, lReg_Status AS INT BYREF ), INT
DECLARE "HIME.DLL", hi_ShredFile                     ALIAS HI_SHREDFILE                     ( lReg_FileName AS INT BYREF, Filemode AS INT BYREF, Passes AS INT BYREF, Algo AS INT BYREF, Parameter AS INT BYREF, lReg_Command AS INT BYREF, lReg_Status AS INT), INT                                             
DECLARE "HIME.DLL", hi_Square                        ALIAS HI_SQUARE                        ( lReg1 AS INT BYREF, lReg_Result AS INT BYREF ), INT                                                                                                                                        
DECLARE "HIME.DLL", hi_StackWipe                     ALIAS HI_STACKWIPE                     ( StackSize AS INT BYREF, Clearance AS INT BYREF ), INT                                                                                                                                      
DECLARE "HIME.DLL", hi_Sub                           ALIAS HI_SUB                           ( lReg1 AS INT BYREF, lReg2 AS INT BYREF, lReg_Result AS INT BYREF ), INT                                                                                                                          
DECLARE "HIME.DLL", hi_SwapReg                       ALIAS HI_SWAPREG                       ( lReg1 AS INT BYREF, lReg2 AS INT BYREF ), INT                                                                                                                                              
DECLARE "HIME.DLL", hi_TrimLZeroes                   ALIAS HI_TRIMLZEROES                   ( lRegIn AS INT BYREF, lRegOut AS INT BYREF ), INT                                                                                                                                           
DECLARE "HIME.DLL", hi_Version                       ALIAS HI_VERSION                       ( ), INT                                                                                                                                                                         
DECLARE "HIME.DLL", HI_XOR                           ALIAS HI_XOR                           ( lReg1 AS INT BYREF, lReg2 AS INT BYREF, lReg_Result AS INT BYREF ), INT                                                                                                                                                                                                                                                                                                                                                                                                   
'